rayvision_api Changelog
=======================
Here you can see the full list of changes between each tagged release.

Version 0.2.0 (September 25th, 2019)
------------------------------------
  - Update tox to support auto deploy (#5)
  - Improve unittest (#4)

Version 0.1.0 (September 13th, 2019)
------------------------------------
  - Create initial api (#2)
